@@ -548,7 +548,9 @@ on_edit_toggled (FontManagerPreviewPage *self, gboolean active)
     g_return_if_fail(self != NULL);
     self->allow_edit = active;
     gtk_text_view_set_editable(GTK_TEXT_VIEW(self->textview), active);
+    gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(self->textview), active);
     gtk_widget_set_can_target(self->textview, active);
+    gtk_widget_grab_focus(self->textview);
     return;
 }
 
@@ -645,6 +647,19 @@ on_swipe_event (FontManagerPreviewPage *self,
     return;
 }
 
+// TODO : Figure out why this is needed.
+// This ensures our PreviewColors CSS is applied to preview widget.
+// Otherwise the CSS fails to apply until the user interacts with it
+// if it's not visible at start up.
+static void
+force_css_update (GtkWidget *preview)
+{
+    g_return_if_fail(preview != NULL);
+    gtk_widget_grab_focus(preview);
+    gtk_widget_queue_draw(preview);
+    return;
+}
+
 static void
 font_manager_preview_page_init (FontManagerPreviewPage *self)
 {
@@ -657,6 +672,7 @@ font_manager_preview_page_init (FontManagerPreviewPage *self)
     self->max_waterfall_size = DEFAULT_WATERFALL_MAX_SIZE;
     self->waterfall_size_ratio = 1.1;
     gtk_widget_add_css_class(GTK_WIDGET(self), FONT_MANAGER_STYLE_CLASS_VIEW);
+    gtk_widget_add_css_class(GTK_WIDGET(self), "FontManagerFontPreviewArea");
     font_manager_widget_set_name(GTK_WIDGET(self), "FontManagerPreviewPage");
     gtk_orientable_set_orientation(GTK_ORIENTABLE(self), GTK_ORIENTATION_VERTICAL);
     g_autoptr(GtkTextTagTable) tag_table = font_manager_text_tag_table_new();
@@ -668,6 +684,7 @@ font_manager_preview_page_init (FontManagerPreviewPage *self)
     g_autoptr(GtkTextBuffer) buffer = gtk_text_buffer_new(tag_table);
     GtkWidget *scroll = gtk_scrolled_window_new();
     self->textview = gtk_text_view_new_with_buffer(buffer);
+    gtk_widget_add_css_class(GTK_WIDGET(self->textview), "FontManagerFontPreviewArea");
     /* gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(self->textview), FALSE); */
     GtkWidget *controls = font_manager_preview_controls_new();
     self->controls = gtk_revealer_new();
@@ -709,6 +726,7 @@ font_manager_preview_page_init (FontManagerPreviewPage *self)
     font_manager_preview_page_set_waterfall_size(self, self->min_waterfall_size, DEFAULT_WATERFALL_MAX_SIZE, 1.0);
     self->menu_button = g_object_ref_sink(gtk_menu_button_new());
     font_manager_set_preview_page_mode_menu_and_actions(GTK_WIDGET(self), self->menu_button, G_CALLBACK(on_mode_action_activated));
+    g_signal_connect_after(self->textview, "map", G_CALLBACK(force_css_update), NULL);
     return;
 }
 
@@ -1062,3 +1080,4 @@ font_manager_set_preview_page_mode_menu_and_actions (GtkWidget *parent,
     return;
 }
 
+
